@@ -28,20 +28,30 @@ def _get_plaintext_from_html(html: str) -> str:
 def _remove_code(html: str) -> str:
     # exclude 'code' tags from link output:
     soup = BeautifulSoup(html, 'lxml')
-    for s in soup.select('code'):
-        s.extract()
+    soup = _remove_code_via_soup(soup)
     html_str = str(soup)
     return html_str
 
 
+def _remove_code_via_soup(soup):
+    for s in soup.select('code'):
+        s.extract()
+    return soup
+
+
 def _remove_del_text(html: str) -> str:
     soup = BeautifulSoup(html, 'lxml')
-    for s in soup.select('del'):
-        s.extract()
+    soup = _remove_del_text_via_soup(soup)
     html_str = str(soup)
     return html_str
 
 
+def _remove_del_text_via_soup(soup):
+    for s in soup.select('del'):
+        s.extract()
+    return soup
+
+
 def _remove_main_formatting(
         html: str, *,
         tags: list[str] = ['p', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6']) -> str:
@@ -50,16 +60,21 @@ def _remove_main_formatting(
 
 def _remove_latex(html: str) -> str:
     soup = BeautifulSoup(html, 'lxml')
-    for s in soup.select('span', {'class': 'MathJax_Preview'}):
-        s.extract()
+    soup = _remove_latex_via_soup(soup)
     html_str = str(soup)
     return html_str
 
 
+def _remove_latex_via_soup(soup):
+    for s in soup.select('span', {'class': 'MathJax_Preview'}):
+        s.extract()
+    return soup
+
+
 def _get_all_latex_from_html_content(html: str) -> list[str]:
     soup = BeautifulSoup(html, 'html.parser')
 
     s_content = soup.find_all('span', {'class': 'MathJax_Preview'},
-                              text=True)
-    latex_found_list = [i.text for i in s_content]
+                              string=True)
+    latex_found_list = [i.string for i in s_content]
     return latex_found_list
